==> haskell-sandi-0.5-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.5
id: sandi-0.5-BUDIl1iM4TQ1whLMF8Ziq6
key: sandi-0.5-BUDIl1iM4TQ1whLMF8Ziq6
license: BSD-3-Clause
maintainer: Magnus Therning <magnus@therning.org>
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: db60a82a013b3437c4b986f6aaecc0fa
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Paths_sandi Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/sandi-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/sandi-0.5
hs-libraries: HSsandi-0.5-BUDIl1iM4TQ1whLMF8Ziq6
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-E4rBVTg9hCWE6hpGqSUOjw
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.5-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.5
id: sandi-0.5-6fD7wvCBmyWDqbAKx8yL6k
key: sandi-0.5-6fD7wvCBmyWDqbAKx8yL6k
license: BSD-3-Clause
maintainer: Magnus Therning <magnus@therning.org>
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: 826aa106ec9e957d480ee200dcaa51c4
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Paths_sandi Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/sandi-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/sandi-0.5
hs-libraries: HSsandi-0.5-6fD7wvCBmyWDqbAKx8yL6k
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-F2avdKCTYaGL08mnA41Iqz
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
